#  (C) Copyright IBM Corp. 2021.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import unittest
import sys
import io
import logging
from ibm_watson_machine_learning.tests.CP4D_35.preparation_and_cleaning import *



class TestWMLClientCloudWithExperiment(unittest.TestCase):
    deployment_id = None
    model_id = None
    scoring_url = None
    library_id = None
    library_url = None
    pipeline_id = None
    pipeline_url = None
    trained_model_id = None
    experiment_id = None
    experiment_run_id = None
    logger = logging.getLogger(__name__)

    @classmethod
    def setUpClass(self):
        TestWMLClientCloudWithExperiment.logger.info("Service Instance: setting up credentials")

        self.wml_credentials = get_wml_credentials()
        self.client = get_client()




        self.space_name = str(uuid.uuid4())

        metadata = {
                     self.client.spaces.ConfigurationMetaNames.NAME: 'client_space_' + self.space_name,
                     self.client.spaces.ConfigurationMetaNames.DESCRIPTION: self.space_name + ' description'
        }

        self.space = self.client.spaces.store(meta_props=metadata)

        TestWMLClientCloudWithExperiment.space_id = self.client.spaces.get_id(self.space)
        print("space_id: ", TestWMLClientCloudWithExperiment.space_id)
        self.client.set.default_space(TestWMLClientCloudWithExperiment.space_id)

    # @classmethod
    # def tearDownClass(self):
    #     clean_cos(self.cos_resource, self.bucket_names)


    def test_01_save_pipeline(self):
        TestWMLClientCloudWithExperiment.logger.info("Save pipelines ...")
        doc= {
             "doc_type": "pipeline",
             "version": "2.0",
             "primary_pipeline": "dlaas_only",
             "pipelines": [
               {
                 "id": "dlaas_only",
                 "runtime_ref": "hybrid",
                 "nodes": [
                   {
                     "id": "training",
                     "type": "model_node",
                     "op": "dl_train",
                     "runtime_ref": "DL",
                     "inputs": [
                     ],
                     "outputs": [],
                     "parameters": {
                       "name": "tf-mnist",
                       "description": "Simple MNIST model implemented in TF",
                       "command": "python3 convolutional_network.py --trainImagesFile ${DATA_DIR}/train-images-idx3-ubyte.gz --trainLabelsFile ${DATA_DIR}/train-labels-idx1-ubyte.gz --testImagesFile ${DATA_DIR}/t10k-images-idx3-ubyte.gz --testLabelsFile ${DATA_DIR}/t10k-labels-idx1-ubyte.gz --learningRate 0.001 --trainingIters 6000",
                     #  "training_lib_href": TestWMLClientCloudWithExperiment.library_url,
                       "compute_configuration_name": "k80",
                       "compute_configuration_nodes": 1,
                       "target_bucket": "wml-dev-results"
                     }
                   }
                 ]
               }
             ],
             "schemas": [
               {
                 "id": "schema1",
                 "fields": [
                   {
                     "name": "text",
                     "type": "string"
                   }
                 ]
               }
             ],
             "runtimes": [
               {
                 "id": "DL",
                 "name": "tensorflow",
                 "version": "1.13-py3.6"
                 }
             ]
            }

        metadata = {
            self.client.repository.PipelineMetaNames.NAME: "my_pipeline",
            self.client.repository.PipelineMetaNames.DOCUMENT: doc,
            self.client.repository.PipelineMetaNames.DESCRIPTION: "python client pipeline test",
            self.client.repository.PipelineMetaNames.TAGS : ["t1","t2"],
            self.client.repository.PipelineMetaNames.CUSTOM: {"value1": "custom test"}
            }


        definition_details = self.client.repository.store_pipeline( meta_props=metadata)
        print(definition_details)
        TestWMLClientCloudWithExperiment.pipeline_id = self.client.repository.get_pipeline_id(definition_details)
        TestWMLClientCloudWithExperiment.logger.info("Saved pipeline uid: " + str(TestWMLClientCloudWithExperiment.pipeline_id))
        print(definition_details)

    def test_02_get_pipeline_details(self):
        TestWMLClientCloudWithExperiment.logger.info("Getting pipeline details ...")
        details_1 = self.client.repository.get_pipeline_details(TestWMLClientCloudWithExperiment.pipeline_id)
        TestWMLClientCloudWithExperiment.logger.info(details_1)
        print(details_1)
        self.assertTrue('my_pipeline' in str(details_1))

    def test_03_list_pipelines(self):
        TestWMLClientCloudWithExperiment.logger.info("List pipelines")
        self.client.repository.list_pipelines()

    def test_04_get_id_url(self):
        def_details = self.client.repository.get_pipeline_details(TestWMLClientCloudWithExperiment.pipeline_id)
        uid = self.client.repository.get_pipeline_id(def_details)
        url = self.client.repository.get_pipeline_href(def_details)
        self.assertIsNotNone(uid)
        self.assertIsNotNone(url)

    def test_05_create_revision(self):
        details_1 = self.client.repository.create_pipeline_revision(TestWMLClientCloudWithExperiment.pipeline_id)
        TestWMLClientCloudWithExperiment.logger.info(details_1)
        print(details_1)
        self.assertTrue('my_pipeline' in str(details_1))

    def test_06_list_revision(self):
        details_1 = self.client.repository.list_pipelines_revisions(TestWMLClientCloudWithExperiment.pipeline_id)
        TestWMLClientCloudWithExperiment.logger.info(details_1)

    def test_07_get_revision_details(self):
        details_1 = self.client.repository.get_pipeline_revision_details(TestWMLClientCloudWithExperiment.pipeline_id,1)
        TestWMLClientCloudWithExperiment.logger.info(details_1)
        self.assertTrue('my_pipeline' in str(details_1))

    def test_08_update_pipeline(self):
        metadata = {
            self.client.repository.PipelineMetaNames.NAME: "updated_name",
            self.client.repository.PipelineMetaNames.DESCRIPTION: "python client pipeline updated description",
            self.client.repository.PipelineMetaNames.TAGS: ["t3"],
            self.client.repository.PipelineMetaNames.CUSTOM: {"value2": "custom test updated"}
        }

        updated_details = self.client.repository.update_pipeline(TestWMLClientCloudWithExperiment.pipeline_id,
                                                                      metadata)
        self.assertTrue('updated_name' in str(updated_details))
        TestWMLClientCloudWithExperiment.logger.info(updated_details)
        print(updated_details)
        self.assertTrue('value1' not in str(updated_details))

    def test_09_save_experiment(self):
        metadata = {
                    self.client.repository.ExperimentMetaNames.NAME: "xxx",
                    self.client.repository.ExperimentMetaNames.TRAINING_REFERENCES: [{
                        "pipeline": {
                            "id": TestWMLClientCloudWithExperiment.pipeline_id,
                           # "id" : "acf894fd-c132-487d-9b42-7e417848bf5d"
                           # "href" : "/v4/pipelines/acf894fd-c132-487d-9b42-7e417848bf5d?rev=e07994ba-3d11-49b9-a6fa-9e64a23c34f8"
                        }
                    }
                    ]
                }


        experiment_details = self.client.repository.store_experiment(meta_props=metadata)
        print(experiment_details)

        TestWMLClientCloudWithExperiment.experiment_id = self.client.experiments.get_id(experiment_details)
        url = self.client.experiments.get_id(experiment_details)

        experiment_specific_details = self.client.experiments.get_details(TestWMLClientCloudWithExperiment.experiment_id)
        self.assertTrue(TestWMLClientCloudWithExperiment.experiment_id in str(experiment_specific_details))
        self.assertIsNotNone(url)

    def test_10_get_experiment_id_url(self):
        def_exp_details = self.client.repository.get_experiment_details(TestWMLClientCloudWithExperiment.experiment_id)
        uid = self.client.repository.get_experiment_id(def_exp_details)
        url = self.client.repository.get_experiment_href(def_exp_details)
        self.assertIsNotNone(uid)
        self.assertIsNotNone(url)

    def test_11_create_experiment_revision(self):
        details_1 = self.client.repository.create_experiment_revision(TestWMLClientCloudWithExperiment.experiment_id)
        TestWMLClientCloudWithExperiment.logger.info(details_1)
        print(details_1)
        self.assertTrue('xxx' in str(details_1))


    def test_12_update_experiment(self):
        metadata = {
            self.client.repository.ExperimentMetaNames.NAME: "my_experiment",
            self.client.repository.ExperimentMetaNames.DESCRIPTION: "mnist best model",
        }

        experiment_details = self.client.repository.update_experiment(TestWMLClientCloudWithExperiment.experiment_id, metadata)
        self.assertTrue('my_exp' in str(experiment_details))
        TestWMLClientCloudWithExperiment.logger.info(experiment_details)
        print(experiment_details)
        self.assertTrue('xxx' not in str(experiment_details))

    def test_13_list_experiment_revision(self):
        details_1 = self.client.repository.list_experiments_revisions(TestWMLClientCloudWithExperiment.experiment_id)
        TestWMLClientCloudWithExperiment.logger.info(details_1)

    def test_14_get_experiment_revision_details(self):
        details_1 = self.client.repository.get_experiment_revision_details(TestWMLClientCloudWithExperiment.experiment_id,1)
        TestWMLClientCloudWithExperiment.logger.info(details_1)
        self.assertTrue('xxx' in str(details_1))

    def test_15_list_experiment(self):
        # stdout_ = sys.stdout
        # captured_output = io.StringIO()  # Create StringIO object
        # sys.stdout = captured_output  # and redirect stdout.
        # self.client.experiments.list()# Call function.
        # sys.stdout = stdout_  # Reset redirect.
        # print(captured_output)
        # self.assertTrue(TestWMLClientCloudWithExperiment.experiment_id in captured_output.getvalue())
        self.client.experiments.list()  # Just to see values.

    # def test_07_save_training(self):
    #     metadata = {
    #
    #         self.client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {"name": "name123",
    #                                                                                 "connection": {
    #                                                                                     "endpoint_url": "https://s3-api.us-geo.objectstorage.softlayer.net",
    #                                                                                     "access_key_id": "zfho4HT7pUIStZvSkDsl",
    #                                                                                     "secret_access_key": "21q66Vvxkhr4uPDacTf8F9fnzMjSUIzsZRtxrYbx"
    #                                                                                 },
    #                                                                                 "location": {
    #                                                                                     "bucket": "fvt-training-results"
    #                                                                                 },
    #                                                                                 "type": "s3"
    #                                                                                 },
    #
    #         self.client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES:
    #             [{
    #                 "name": "training_input_data",
    #                 "type": "s3",
    #                 "connection": {
    #                     "endpoint_url": "https://s3-api.us-geo.objectstorage.softlayer.net",
    #                     "access_key_id": "zfho4HT7pUIStZvSkDsl",
    #                     "secret_access_key": "21q66Vvxkhr4uPDacTf8F9fnzMjSUIzsZRtxrYbx"
    #                 },
    #                 "location": {
    #                     "bucket": "wml-dev"
    #                 },
    #                 "schema": {
    #                     "id": "id123_schema",
    #                     "fields": [
    #                         {
    #                             "name": "text",
    #                             "type": "string"
    #                         }
    #                     ]
    #                 }
    #             }]
    #         ,
    #         self.client.training.ConfigurationMetaNames.EXPERIMENT_UID: TestWMLClientCloudWithExperiment.experiment_id
    #
    #     }
    #
    #
    #     training_details = self.client.training.run(meta_props=metadata)
    #
    #     TestWMLClientCloudWithExperiment.trained_model_id = self.client.training.get_id(training_details)
    #     url = self.client.training.get_id(training_details)
    #
    #     training_details = self.client.training.get_details(TestWMLClientCloudWithExperiment.trained_model_id)
    #     self.assertTrue(TestWMLClientCloudWithExperiment.trained_model_id in str(training_details))
    #     self.assertIsNotNone(url)
    #
    # def test_09_list_trainings(self):
    #     stdout_ = sys.stdout
    #     captured_output = io.StringIO()  # Create StringIO object
    #     sys.stdout = captured_output  # and redirect stdout.
    #     self.client.training.list()# Call function.
    #     sys.stdout = stdout_  # Reset redirect.
    #     self.assertTrue(TestWMLClientCloudWithExperiment.trained_model_id in captured_output.getvalue())
    #     self.client.training.list()  # Just to see values.
    #
    # def test_10_delete_training(self):
    #     self.client.training.delete(TestWMLClientCloudWithExperiment.trained_model_id)
    #

    def test_16_delete_experiment(self):
        self.client.repository.delete(TestWMLClientCloudWithExperiment.experiment_id)

    def test_17_delete_pipeline_library(self):
        self.client.repository.delete(TestWMLClientCloudWithExperiment.pipeline_id)


if __name__ == '__main__':
    unittest.main()



#  (C) Copyright IBM Corp. 2021.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import json,ast
from ibm_watson_machine_learning.libs.repo.mlrepository import MetaNames, MetaProps
from ibm_watson_machine_learning.libs.repo.swagger_client.models.ml_assets_create_functions_output import MlAssetsCreateFunctionsOutput
from ibm_watson_machine_learning.libs.repo.util.library_imports import LibraryChecker
from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.function_loader import FunctionLoader
from ibm_watson_machine_learning.libs.repo.mlrepository.wml_function_artifact import WmlFunctionArtifact
lib_checker = LibraryChecker()

class FunctionAdapter(object):
    """
    Adapter creating function artifact using output from service.
    """
    @staticmethod
    def __strip_output(output):
        return ast.literal_eval(json.dumps(output))

    def __init__(self, function_output, client):
        self.function_output = function_output
        self.client = client
        self.function_entity = self.function_output.entity
        if function_output is not None and not isinstance(function_output, MlAssetsCreateFunctionsOutput):
            raise ValueError('Invalid type for pipeline: {}'.format(function_output.__class__.__name__))


    def artifact(self):

        function_artifact_builder = type(
                "WmlFunctionArtifact",
                (FunctionLoader, WmlFunctionArtifact, object),
                {}
            )

        prop_map = {
            MetaNames.CREATION_TIME: self.function_output.metadata.created_at,
            MetaNames.LAST_UPDATED: self.function_output.metadata.modified_at
        }

        if self.function_entity.get('description', None) is not None:
            prop_map[MetaNames.FUNCTIONS.DESCRIPTION] = self.function_entity['description']

        if self.function_entity.get('tags', None) is not None:
            prop_map[MetaNames.FUNCTIONS.TAGS] = self.function_entity.get('tags')

        if self.function_entity.get('type', None) is not None:
            prop_map[MetaNames.FUNCTIONS.TYPE] = self.function_entity.get('type')

        if self.function_entity.get('runtime', None) is not None:
            if self.function_entity.get('runtime').get('url') is not None:
              prop_map[MetaNames.RUNTIMES.URL] = self.function_entity.get('runtime')['url']

            if self.function_entity.get('runtime').get('content_url') is not None:
              prop_map[MetaNames.RUNTIMES.CONTENT_URL] = self.function_entity.get('runtime')['content_url']

            if self.function_entity.get('runtime').get('custom_libraries') is not None:
              prop_map[MetaNames.RUNTIMES.CUSTOM_LIBRARIES_URLS] = self.function_entity.get('runtime')['custom_libraries']

            if self.function_entity.get('runtime').get('description') is not None:
              prop_map[MetaNames.RUNTIMES.DESCRIPTION] = self.function_entity.get('runtime')['description']

            if self.function_entity.get('runtime').get('platform') is not None:
             prop_map[MetaNames.RUNTIMES.PLATFORM] = self.function_entity.get('runtime')['platform']

            if self.function_entity.get('runtime').get('name') is not None:
             prop_map[MetaNames.RUNTIMES.NAME] = self.function_entity.get('runtime')['name']

        if self.function_entity.get('input_data_schema', None) is not None:
           prop_map[MetaNames.FUNCTIONS.INPUT_DATA_SCHEMA] = self.function_entity.get('input_data_schema')

        if self.function_entity.get('output_data_schema', None) is not None:
           prop_map[MetaNames.FUNCTIONS.OUTPUT_DATA_SCHEMA] = self.function_entity.get('output_data_schema')

        if self.function_entity.get('sample_scoring_input', None) is not None:
            prop_map[MetaNames.FUNCTIONS.SAMPLE_SCORING_INPUT] = self.function_entity.get('sample_scoring_input')


        name = self.function_entity.get('name', None)

        function_url = self.function_output.metadata.url
        function_id = function_url.split("/functions/")[1].split("/")[0]

        function_artifact = function_artifact_builder(
            function_id,
            name,
            MetaProps(prop_map))

        function_artifact.client = self.client

        if self.function_output.entity.get('function_revision') is not None:
            if self.function_output.entity['function_revision'].get('content_url') is not None:
              prop_map[MetaNames.FUNCTIONS.CONTENT_URL] = self.function_output.entity['function_revision']['content_url']
        else:
            prop_map[MetaNames.FUNCTIONS.CONTENT_URL] =   self.function_output.entity['content_url']

        if self.function_output.entity.get('function_revision') is not None:
            self.revision_output = self.function_output.entity['function_revision']
            revision_url = self.revision_output['url']
            function_url = revision_url.split("/revisions")[0]

            revision_id = revision_url.split("/revisions/")[1].split("/")[0]

            version_prop_map = {
                MetaNames.FUNCTIONS.REVISION: revision_id,
                MetaNames.FUNCTIONS.REVISION_URL:revision_url,
                MetaNames.FUNCTIONS.URL:function_url
            }

        else:
            revision_url = self.function_output.metadata.url
            revision_id = revision_url.split("/revisions/")[1].split("/")[0]
            function_url = revision_url.split("/revisions")[0]

            version_prop_map = {
                MetaNames.FUNCTIONS.REVISION: revision_id,
                MetaNames.FUNCTIONS.REVISION_URL:revision_url,
                MetaNames.FUNCTIONS.URL:function_url
            }


        function_artifact.meta.merge(MetaProps(version_prop_map))
        function_artifact._content_href = prop_map[MetaNames.FUNCTIONS.CONTENT_URL]
   
        return function_artifact



#  (C) Copyright IBM Corp. 2021.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import unittest

try:
    from sklearn.externals import joblib
except ImportError:
    import joblib

from ibm_watson_machine_learning.helpers import pipeline_to_script


class TestPipelineToScript(unittest.TestCase):
    model_path = './autoai/artifacts/bank/bank_model_333.pickle'
    pipeline = None

    @classmethod
    def setUp(cls) -> None:
        cls.pipeline = joblib.load(cls.model_path)

    def test_01__create_python_script(self):
        pipeline_to_script(pipeline=self.pipeline)

        script = None
        try:
            with open("pipeline_script.py") as f:
                script = f.read()

        except FileNotFoundError:
            self.assertIsNone(script, msg="pipeline_script.py file not found!")

        print(script)


if __name__ == '__main__':
    unittest.main()



#  (C) Copyright IBM Corp. 2021.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from ibm_watson_machine_learning.libs.repo.mlrepository import MetaNames
from ibm_watson_machine_learning.libs.repo.mlrepository import MetaProps
from ibm_watson_machine_learning.libs.repo.mlrepository import ModelArtifact
from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.tensorflow_pipeline_reader import TensorflowPipelineReader
from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.generic_file_reader import GenericFileReader
from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.version_helper import TensorflowVersionHelper
from ibm_watson_machine_learning.libs.repo.util.library_imports import LibraryChecker
from ibm_watson_machine_learning.libs.repo.base_constants import *
from .python_version import PythonVersion
from ibm_watson_machine_learning.libs.repo.util.unique_id_gen import uid_generate
from ibm_watson_machine_learning.libs.repo.util.exceptions import UnmatchedKerasVersion
import os, shutil, tarfile, json

class GenericArchivePipelineModelArtifact(ModelArtifact):
    """
    Class of  PMML,SPSS-MODELER,CAFFE,CAFFE2,PYTORCH,TORCH,MXNET,THEANO,BLUECONNECT and MXNET model artifacts created
    with MLRepositoryCLient.

    """
    def __init__(self,
                 generic_artifact,
                 uid=None,
                 name=None,
                 meta_props=MetaProps({}),):

        super(GenericArchivePipelineModelArtifact, self).__init__(uid, name, meta_props)

        self.ml_pipeline_model = generic_artifact
        self.ml_pipeline = None     # no pipeline or parent reference

    def pipeline_artifact(self):
        """
        Returns None. Pipeline is not implemented for archive model.
        """
        pass

    def reader(self):
        """
        Returns reader used for getting archive model content.

        :return: reader for TensorflowPipelineModelArtifact.pipeline.Pipeline
        :rtype: TensorflowPipelineReader
        """
        try:
            return self._reader
        except:
            self._reader = GenericFileReader(self.ml_pipeline_model)
            return self._reader

    def _copy(self, uid=None, meta_props=None):
        if uid is None:
            uid = self.uid

        if meta_props is None:
            meta_props = self.meta

        return GenericArchivePipelineModelArtifact(
            self.ml_pipeline_model,
            uid=uid,
            name=self.name,
            meta_props=meta_props
        )


    ## Below methods is to validate the caffe model archive

    def unzip_artifact(self):
        try:
            tar = tarfile.open(self.ml_pipeline_model, 'r:gz')
        except Exception as ex:
            raise IOError('Unable to read the compressed archive file in {0} due to '
                          'error "{1}". '
                          'Ensure a valid tar archive is compressed in gzip format.'
                          .format(self.ml_pipeline_model, ex))
        return tar

    def extract_tar_file(self):
        tar_url=self.ml_pipeline_model
        extract_dir =  uid_generate(5)
        tar = self.unzip_artifact()

        if os.path.exists(extract_dir):
            shutil.rmtree(extract_dir)
        os.makedirs(os.path.join("./", extract_dir))
        tar = tarfile.open(tar_url, 'r')
        for item in tar:
            tar.extract(item, extract_dir)

        return extract_dir





    def _check_multiple_ext_file(self, path, expected_ext):
        file_list = os.listdir(path)
        ext_count = 0
        for file_name in file_list:
            _, ext = os.path.splitext(os.path.join(path, file_name))
            if ext == expected_ext:
                ext_count += 1
            if ext_count > 1:
                return True
        return False

    def is_valid_caffe_archive(self,path):
        file_list = os.listdir(path)
        expected_files_ext = {'.json': False, '.prototxt': False, '.caffemodel': False}
        for file_name in file_list:
            name, ext = os.path.splitext(file_name)
            if ext in expected_files_ext:
                expected_files_ext[ext] = True

        for key in expected_files_ext:
            if not expected_files_ext[key]:
                shutil.rmtree(path)
                raise ValueError("Given archive doesn't have a file with extension {}".format(key))

        expected_file_name = "deployment-meta.json"
        try:
            with open(os.path.join(path, expected_file_name)) as data_file:
                json_dict = json.load(data_file)
        except Exception:
            shutil.rmtree(path)
            raise ValueError("The given archive doesn't have the file deployment-meta.json")


        if 'output_layers' not in json_dict:
            shutil.rmtree(path)
            raise ValueError("deployment-meta.json file does not have key output_layers")


        if 'network_definitions_file_name' in json_dict:
            nw_file_name = json_dict['network_definitions_file_name']
            if nw_file_name not in file_list:
                shutil.rmtree(path)
                raise ValueError("Given archive doesn't have a file defined for Key 'network_definitions_file_name' {}")

        if 'weights_file_name' in json_dict:
            weights_file_name = json_dict['weights_file_name']
            if weights_file_name not in file_list:
                shutil.rmtree(path)
                raise ValueError("Given archive doesn't have a file defined for Key 'weights_file_name' {}")

        if self._check_multiple_ext_file(path,'.prototxt'):
            if 'network_definitions_file_name' not in json_dict:
                shutil.rmtree(path)
                raise ValueError("Key 'network_definitions_file_name' expected in deployment-meta.json")

        if self._check_multiple_ext_file(path,'.caffemodel'):
            if 'weights_file_name' not in json_dict:
                shutil.rmtree(path)
                raise ValueError("Key 'weights_file_name' expected in deployment-meta.json")

        shutil.rmtree(path)




#  (C) Copyright IBM Corp. 2021.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from ibm_watson_machine_learning.libs.repo.mlrepository import ModelArtifact


class HybridModelArtifact(ModelArtifact):
    """
    Class representing Hybrid model artifact
    """
    def __init__(self, uid, name, meta_props):
        """
        Constructor for Hybrid model artifact
        :param uid: unique id for Hybrid model artifact
        :param name: name of the model
        :param metaprops: properties of the model and model artifact
        """
        super(HybridModelArtifact, self).__init__(uid, name, meta_props)

